@@ -1,7 +1,6 @@
 """Encapsulate the awful XML response and provide helpful functions."""
 
 import xmltodict
-from pylru import lrudecorator
 
 
 def get_success_msg(xml):
@@ -23,7 +22,6 @@ def get_data_field(xml, field):
     return value or ""
 
 
-@lrudecorator(64)
 def get_data(xml):
     """Return the 'Data' entry from LM's XML as a dict"""
     success_xml_entry = _get_xml_field(xml, "Success")
@@ -46,7 +44,10 @@ def parse_to_dict(xml):
 def _get_xml_field(xml, field, data_field=None):
     """return the string specified, or None if not present"""
     try:
-        xml_dict = xmltodict.parse(xml)
+        if isinstance(xml, dict):
+            xml_dict = xml
+        else:
+            xml_dict = xmltodict.parse(xml)
         try:
             response_dict = xml_dict["Response"]
             if data_field is None:
