@@ -1412,7 +1412,7 @@ class LoadMaster(BaseKempAppliance):
                         virt_serv = self.build_virtual_service(service_data,
                                                                vs)
             else:
-                virt_serv = self.build_virtual_service(service_data, response)
+                virt_serv = self.build_virtual_service(service_data, data)
             real_servers = cast_to_list(service_data.get("Rs", []))
             for server_data in real_servers:
                 rs = virt_serv.build_real_server(server_data)
